pub struct LuRef<'a, I: Index, T> { /* private fields */ }Expand description
sparse $LU$ factorization wrapper
Implementations
Sourceimpl<'a, I: Index, T> LuRef<'a, I, T>
impl<'a, I: Index, T> LuRef<'a, I, T>
Sourcepub unsafe fn new_unchecked(
symbolic: &'a SymbolicLu<I>,
numeric: &'a NumericLu<I, T>,
) -> Self
pub unsafe fn new_unchecked( symbolic: &'a SymbolicLu<I>, numeric: &'a NumericLu<I, T>, ) -> Self
creates $LU$ factors from their components
safety
the numeric part must be the output of SymbolicLu::factorize_numeric_lu, called with a
matrix having the same symbolic structure as the one used to create symbolic
Sourcepub fn symbolic(self) -> &'a SymbolicLu<I>
pub fn symbolic(self) -> &'a SymbolicLu<I>
returns the symbolic structure of the $LU$ factorization
Sourcepub fn solve_in_place_with_conj(
self,
conj: Conj,
rhs: MatMut<'_, T>,
par: Par,
stack: &mut MemStack,
)where
T: ComplexField,
pub fn solve_in_place_with_conj(
self,
conj: Conj,
rhs: MatMut<'_, T>,
par: Par,
stack: &mut MemStack,
)where
T: ComplexField,
solves the equation $A x = \text{rhs}$ and stores the result in rhs, implicitly
conjugating $A$ if needed
panics
- panics if
self.nrows() != self.ncols() - panics if
rhs.nrows() != self.nrows()
Sourcepub fn solve_transpose_in_place_with_conj(
self,
conj: Conj,
rhs: MatMut<'_, T>,
par: Par,
stack: &mut MemStack,
)where
T: ComplexField,
pub fn solve_transpose_in_place_with_conj(
self,
conj: Conj,
rhs: MatMut<'_, T>,
par: Par,
stack: &mut MemStack,
)where
T: ComplexField,
solves the equation $A^\top x = \text{rhs}$ and stores the result in rhs,
implicitly conjugating $A$ if needed
panics
- panics if
self.nrows() != self.ncols() - panics if
rhs.nrows() != self.nrows()