pub struct SymbolicLu<I> { /* private fields */ }Expand description
the symbolic structure of a sparse $LU$ decomposition
Implementations
Sourceimpl<I: Index> SymbolicLu<I>
impl<I: Index> SymbolicLu<I>
Sourcepub fn col_perm(&self) -> PermRef<'_, I>
pub fn col_perm(&self) -> PermRef<'_, I>
returns the fill-reducing column permutation that was computed during symbolic analysis
Sourcepub fn factorize_numeric_lu_scratch<T>(
&self,
par: Par,
params: Spec<PartialPivLuParams, T>,
) -> StackReqwhere
T: ComplexField,
pub fn factorize_numeric_lu_scratch<T>(
&self,
par: Par,
params: Spec<PartialPivLuParams, T>,
) -> StackReqwhere
T: ComplexField,
computes the size and alignment of the workspace required to compute the numerical $LU$ factorization
Sourcepub fn solve_in_place_scratch<T>(&self, rhs_ncols: usize, par: Par) -> StackReqwhere
T: ComplexField,
pub fn solve_in_place_scratch<T>(&self, rhs_ncols: usize, par: Par) -> StackReqwhere
T: ComplexField,
computes the size and alignment of the workspace required to solve the equation $A x = b$
Sourcepub fn solve_transpose_in_place_scratch<T>(
&self,
rhs_ncols: usize,
par: Par,
) -> StackReqwhere
T: ComplexField,
pub fn solve_transpose_in_place_scratch<T>(
&self,
rhs_ncols: usize,
par: Par,
) -> StackReqwhere
T: ComplexField,
computes the size and alignment of the workspace required to solve the equation $A^\top x = b$
Sourcepub fn factorize_numeric_lu<'out, T: ComplexField>(
&'out self,
numeric: &'out mut NumericLu<I, T>,
A: SparseColMatRef<'_, I, T>,
par: Par,
stack: &mut MemStack,
params: Spec<PartialPivLuParams, T>,
) -> Result<LuRef<'out, I, T>, LuError>
pub fn factorize_numeric_lu<'out, T: ComplexField>( &'out self, numeric: &'out mut NumericLu<I, T>, A: SparseColMatRef<'_, I, T>, par: Par, stack: &mut MemStack, params: Spec<PartialPivLuParams, T>, ) -> Result<LuRef<'out, I, T>, LuError>
computes a numerical $LU$ factorization of $A$